@@ -1,7 +1,7 @@
 import os
 
-from django.conf import settings
-
+# from django.conf import settings
+from django_sourcerer import settings
 from django_sourcerer.import_datas import parsing_config_file
 from django_sourcerer.import_datas.import_csv_data import HandleCsvData
 
